<?xml version='1.0'?>
<!DOCTYPE xsl:stylesheet [ ]>
<xsl:stylesheet 
  xmlns:xsl='http://www.w3.org/1999/XSL/Transform' version='1.0' 
  xmlns:xalan='http://xml.apache.org/xalan'
  xmlns:java='http://xml.apache.org/xalan/java'
  xmlns:sesame='xalan://nl.cwi.ins2.smartstyle.xsltsesame.SesameClientXML'
  extension-element-prefixes='sesame'
  exclude-result-prefixes='java'
>
  <xsl:param name='date'>unknown_time</xsl:param>
  <xsl:param name='user'>default_user</xsl:param>
  <xsl:include href="setparams.xsl"/>

  <xsl:template match="/">
   <xsl:call-template name="setSesameParams"/>
   <xsl:apply-templates/>
  </xsl:template>

  <xsl:output 
	encoding="utf-8" 
	method="xml"
	standalone="yes"
	indent="yes"
	omit-xml-declaration="no"
	doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
	doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"
  />

  <xsl:template match='/grouppage'>
    <xsl:variable name='server'    select='//sesame/server'/>
    <xsl:variable name='theme'     select='theme'/>
    <!--xsl:variable name='env'       selects'xalan:checkEnvironment()'/ temp disabled-->
    <xsl:variable name='user_info'>
      <sesame:serql query='
        select name from {{(!http://www.cwi.nl/~media/publications/ins.rdf#{$user})}} (foaf:name) {{name}}
        using namespace foaf = (!http://xmlns.com/foaf/0.1/)
       '/>
    </xsl:variable>
    <html>
      <xsl:comment>
	Do not edit this page, it is automatically generated by running make in cuypers/www/ins2
	on <xsl:value-of select="$date"/>
	for <xsl:value-of select="$user"/>
      </xsl:comment>
      <head>
        <xsl:copy-of select="//styles/defaultstyle/*"/>
        <xsl:copy-of select="//styles/altstyle/*"/>
        <link rel="meta" type="application/rdf+xml" title="FOAF" href="foaf.rdf" />
        <title><xsl:value-of select="$theme"/></title>
	<style type="text/css">
         <xsl:copy-of select="//styles/localstyle/text()"/>
        </style>
      </head>
      <body>
        <h1><xsl:copy-of select="$theme/text()|$theme/*"/></h1>
	<xsl:copy-of select="navigation/*"/>
	<div class="mainBody">
         <xsl:choose>
         <xsl:when test="string($user)!=string('default_user')">
            Note: personalized page for
            <xsl:copy-of select="xalan:nodeset($user_info)/tableQueryResult/tuple/*"/>
            <xsl:copy-of select="intranet/*"/>
            <xsl:call-template name="homepages">
              <xsl:with-param name="server" select="$server"/>
            </xsl:call-template>
            <xsl:copy-of select="misclinks/*"/>
         </xsl:when>
         <xsl:otherwise>
	  <xsl:copy-of select="disclaimer/*"/>
	  <xsl:copy-of select="explain/*"/>
          <xsl:call-template name="homepages">
            <xsl:with-param name="server" select="$server"/>
          </xsl:call-template>
	  <xsl:copy-of select="intranet/*"/>
	  <xsl:copy-of select="misclinks/*"/>
         </xsl:otherwise>
         </xsl:choose>

	</div>
        <xsl:copy-of select="logos/*"/>
        <!--p style="font-size: small; margin: 1%; float: right; width: 10em; background-color: transparent; border: 1pt solid;">
	  Java: <xsl:value-of select="$env//item[@key='java.version']"/><br/>
        Sesame: <xsl:value-of select="java:org.openrdf.sesame.server.SesameServer.getVersion()"/><br/>
	        <xsl:value-of select="$env//item[@key='version.xalan2x']"/><br/>
	        <xsl:value-of select="$env//item[@key='version.xerces2']"/><br/>
        </p-->
      </body>
    </html>
    
  </xsl:template>

  <xsl:template name="member">  
   <xsl:param name="homepage" select="default"/>
   <xsl:param name="memberURI" select="default"/>
   <xsl:param name="name">Not given</xsl:param>
   <xsl:param name="server">Not given</xsl:param>
   <xsl:param name="photo">Not given</xsl:param>
   <xsl:variable name='isProf'>
      <sesame:serql query='select T from {{(!{$memberURI})}} (rdf:type) {{T}}
where T = (!http://www.ontoweb.org/ontology/1#FullProfessor)'/>
   </xsl:variable>
    <xsl:variable name='isPhD'>
      <sesame:serql query='select T from {{(!{$memberURI})}} (rdf:type) {{T}}
where T = (!http://www.ontoweb.org/ontology/1#PhDStudent)
      '/>
    </xsl:variable>
   <span>
         <xsl:attribute name="style">overflow: hidden; text-align: center; float: left; height: 200px; width: 180px; margin-left: 5px; </xsl:attribute>
     <a>
      <xsl:attribute name="href">
         <xsl:value-of select="$homepage"/></xsl:attribute>
         <xsl:if test="string($photo)!=string('')">
           <img style="height: 150px; border-style: none;">
		<xsl:attribute name="src"><xsl:value-of select="$photo"/></xsl:attribute>
		<xsl:attribute name="alt">Photo of <xsl:value-of select="$name"/></xsl:attribute>
           </img>
	 </xsl:if>
	<br/>
           <xsl:value-of select="$name"/>
           <xsl:if test="string($name)=string('')"><xsl:value-of select="$homepage"/></xsl:if>
    </a>
    (<a><xsl:attribute name="href"><xsl:value-of select="$server"/>/explorer/show.jsp?useLabels=yes&amp;repository=ins2research&amp;value=&lt;<xsl:value-of select='java:java.net.URLEncoder.encode($memberURI,"UTF-8")'/>&gt;</xsl:attribute>explore</a>)
   </span>
  </xsl:template>

    <xsl:template name="homepages">
    <xsl:param name="server">Not given</xsl:param>
    <xsl:variable name='members'>
      <sesame:serql query='
select Homepage, L, MemberID, Photo from 
  {{(!http://db.cwi.nl/projecten/thema.php4?themanr=6)}} (foaf:member) {{MemberID}} [(rdfs:label) {{L}}]; 
  [(foaf:homepage) {{Homepage}}; (foaf:img) {{Photo}}]
using namespace foaf = (!http://xmlns.com/foaf/0.1/)
       '/>
    </xsl:variable>
          <div class="section">
           <h2>INS2 homepages:</h2>
            <xsl:for-each select="xalan:nodeset($members)/tableQueryResult/tuple">
              <xsl:sort select="literal[1]"/>
              <xsl:call-template name="member">
                <xsl:with-param name="homepage"  select="*[1]"/>
                <xsl:with-param name="name"      select="*[2]"/>
                <xsl:with-param name="memberURI" select="*[3]"/>
                <xsl:with-param name="photo"     select="*[4]"/>
                <xsl:with-param name="server" select="$server"/>
              </xsl:call-template>
            </xsl:for-each>
          <p style="clear: both;"/>
          </div>
  </xsl:template>
</xsl:stylesheet>
