/** 
 *  Copyright (C) 2004 CWI
 *
 *  Contact:
 *  CWI
 *  Kruislaan 413
 *  P.O. Box 94079
 *  1090 GB  AMSTERDAM
 *  The Netherlands
 *  http://www.cwi.nl/
 * 
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package nl.cwi.ins2.smartstyle.xsltsesame;

import java.io.ByteArrayOutputStream;
import java.io.StringReader;
import java.io.IOException;
import java.util.Properties;
import java.net.URL;

import org.w3c.dom.Document;
import org.xml.sax.InputSource;
import org.apache.xerces.parsers.DOMParser;

import org.apache.xalan.extensions.XSLProcessorContext;
import org.apache.xalan.templates.ElemExtensionCall;
import org.apache.xalan.templates.Stylesheet;


import org.openrdf.sesame.Sesame;
import org.openrdf.sesame.constants.QueryLanguage;
import org.openrdf.sesame.query.XmlQueryResultWriter;
import org.openrdf.sesame.repository.SesameService;
import org.openrdf.sesame.repository.SesameRepository;
import org.openrdf.sesame.repository.remote.HTTPService;

/**
 * Simple Xalan XSLT extension to query Sesame from within XSLT and 
 * to return the RQL/SeRQL query results as an XML tree.
 *
 * See http://homepages.cwi.nl/~media/cuypers/java/ for examples and more info
 *
 * @author  Jacco.van.Ossenbruggen@cwi.nl 
 * @version $Revision: 1.15 $
 *
 **/

public class SesameClientXML
{
    protected boolean      verbose    = true;
    protected String       repository = "exampleRepository"; 
    protected URL          serverURL  = new URL("http://example.com/sesame");
    protected SesameService  service    = null;
    protected SesameRepository client = null;

    public SesameClientXML () throws Exception
    {
	System.setProperty("org.xml.sax.driver", "org.apache.xerces.parsers.SAXParser");
    }  
    
    public String setRepository(String rep) throws Exception {
	String oldrep = repository;
	repository = rep;
	return oldrep;
    }

    public String setServer(String url) throws Exception {
	String oldurl = serverURL.toString();
	serverURL = new URL(url);
	service = Sesame.getService(serverURL);
	client = service.getRepository(repository);
	return oldurl;
    }
    public boolean setVerbosity(boolean v) throws Exception {
	boolean oldvalue = verbose;
	verbose = v;
	return oldvalue;
    }

    public void serql(XSLProcessorContext c, ElemExtensionCall e) throws Exception
    {
	Stylesheet stylesheet = c.getStylesheet(); 
	String q  = e.getAttribute("query",c.getContextNode(),c.getTransformer());
	String em = e.getAttribute("escapeMode",c.getContextNode(),c.getTransformer());
	String tq = null;
	if (em != null && em.equals("off"))
		tq = q;
	else 	
		tq = q.replaceAll("\\(([0-9a-zA-Z:/.=!@#$&?~_-]+)\\)", "<$1>");
	
	if (verbose) 
		System.err.println("SesameClientXML: Sesame Version "+org.openrdf.sesame.server.SesameServer.getVersion());
	try {
	    if (verbose) 
		System.err.println("SesameClientXML: Sending SeRQL query (to "+repository+"@"+serverURL+") "+tq);

	    ByteArrayOutputStream baos = new ByteArrayOutputStream(1024);
	    XmlQueryResultWriter listener = new XmlQueryResultWriter(baos, true);
            client.performTableQuery(QueryLanguage.SERQL, tq, listener);
            if (verbose)
                System.err.println("SesameClientXML: Query processed");

	    String s = new String(baos.toByteArray(), "UTF-8");
            if (verbose) { 
		System.err.println("SesameClientXML: results: " +s);
	    }
	    DOMParser parser = new DOMParser();
	    parser.parse(new InputSource(new StringReader(s)));
	    Document doc = parser.getDocument();
	    
	    if (c != null && doc != null) c.outputToResultTree(stylesheet, doc);
	    else if (c == null) System.err.println("SesameClientXML: XSLTcontext is null");
	    else if (doc == null) System.err.println("SesameClientXML: Result document is null");

            if (verbose) { 
	        System.err.println("SesameClientXML: returned outputToResultTree");
	    }
	 } catch (Exception ex){
            System.err.println("SesameXML error. seRQL: Query failed: "+ex);
 	    ex.printStackTrace();
	    System.err.println("SesameClientXML: failed to process SeRQL query (to "+repository+"@"+serverURL+") "+tq);
	 }
    }
}

